#
# Platon/Template/Plugin/Interval.pm
#
# Developed by Lubomir Host 'rajo' <rajo AT platon.sk>
# Copyright (c) 2004-2006 Platon Group, http://platon.sk/
# Licensed under terms of GNU General Public License.
# All rights reserved.
#
# Changelog:
# 18/04/2004 - created
#

# $Platon: web-apps/fastcgi-gallery/_modules/Platon/Template/Plugin/Interval.pm,v 1.1 2005/09/07 13:36:58 rajo Exp $

package Platon::Template::Plugin::Interval;

use strict;
use Carp;
use Time::HiRes qw(gettimeofday tv_interval);
use Template::Plugin;
use Template::Exception;

use base qw( Template::Plugin );
use vars qw( $VERSION $DEBUG );

$VERSION  = sprintf("%d.%02d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/);
$DEBUG    = 0 unless defined $DEBUG;

sub new
{ #{{{
    my $class   = shift;
    my $context = shift;
    my $self    = ref $class ? $class : bless { 
		_CONTEXT => $context, 
		_STH     => [ ],
    }, $class;

	$self->{start_time} = shift;
	my $precision  = shift;
	$self->{precision}  = defined ($precision) ? $precision : 1E3;
	
    bless $self, $class;

    return $self;
} # }}}

sub interval
{ # {{{
	my ($self) = @_;
	my $precision = $self->{precision};

	my $curr_time = Time::HiRes::gettimeofday;

	return (int($precision * ($curr_time - $self->{start_time})) / $precision);
} # }}}

1;

__END__

=head1 NAME

interval - <<<description of module>>>

=head1 SYNOPSIS

  use Platon::Template::Plugin::Interval;

  my $xxx = new Platon::Template::Plugin::Interval;

=head1 DESCRIPTION

The interval module allows you ...
<<<your description here>>>

=head2 EXPORT

<<here describe exported methods>>>

=head1 SEE ALSO

=head1 AUTHORS

Lubomir Host 'rajo', <rajo AT platon.sk>

=cut

# vim: ts=4
# vim600: fdm=marker fdl=0 fdc=3

